### Goal

There are a lot of bird-perspective greyscale FLIR-images made by a drone, which don't get stitched well together automatically.
But we have geo-coordinates as metadata.

It will be manual work, but maybe we can semi-automatize it.

### How it works

The process has three steps:  
1. Putting the tiles onto an SVG-canvas using a python script.  
   You may want to try around with the settings (scaling, rotation, etc) of the CLI tool until you get a useful SVG.
2. Manual Editing of the SVG.  
   There are errors in the GPS data and FLIR data.
   Correct them manually using Inkscape or similar Vector Graphics software.
3. Converting the SVG canvas into a GeoTIFF  
   The script produces 16-bit greyscale PNG-Files, representing the temperature, and exports the SVG into a big PNG image.  
   This PNG image gets then projected and converted into a GeoTIFF, using temperature information from the grey-scale value of the PNG 

The two python scripts:

* `gis-svg-stitcher.py` for putting the tiles onto an SVG canvas  
  Example usage:
  ```
  python3 gis-svg-stitcher.py relative_path_to_the_imagefiles --scale=15 --base_rotation=115 --rotation_corr_left=28
  ```
  It produces a file called `map.svg`

* `convert-svg-to-geotiff.py` for converting the (edited) SVG canvas 
  Example usage:
  ```
  python3 convert-svg-to-geotiff.py relative_path_to_the_imagefiles/map.svg output.tiff
  ```


### Requirements

* python3 + pip
* inkscape
* firefox

### Installation

Install Python3, Inkscape and Firefox.

Then clone repo and install script dependencies:
```
git clone https://git.notice.at/redplanet/deep-crop.git
cd deep-crop
pip3 install -r requirements.txt
```

### How to use

Use the scripts. Use the `--help` flag for more information:

```
python3 gis-svg-stitcher.py --help
```
and
```
python3 convert-svg-to-geotiff.py --help
```


### Licence

This work is licenced under GPLv3+.

However, the scripts are built upon libraries and programs with some different licences:

* lxml - BSD
* wand - MIT
* PyExifTool - GPLv3+/BSD
* argparse - Python Software Foundation License
* pyproj - MIT
* flirimageextractor - MIT
* opencv-contrib-python - MIT
* numpy - BSD
* pathlib - MIT
* selenium - Apache 2.0
* rasterio - BSD
* Mozilla Firefox - MPL
* Inkscape - GPLv2